# Week 8: Displaying Data Visually Part 2
# Brett Favaro
# Oct 23, 2019

library(tidyverse)
library(lubridate)

perch <- read.csv("data/YPerchTL.csv")

###################################################
# IF YOU WANT TO SKIP THIS FILE, JUST RUN THIS:

perch$sampledate <- mdy(perch$sampledate)

perch <- perch %>%
  select(-lakeid) %>%
  select(-spname) %>% 
  select(-year4)

# THEN OPEN 002_plot_exercise.R
###################################################


# Data are from: http://derekogle.com/fishR/data/data-html/YPerchTL.html
# obtained 23 Oct 2019

#Data
#lakeid: Lake name (all TR=Trout Lake)
#year4: Year of capture
#sampledate: Date of capture
#gearid: Capture gear type – beach seine (BSEINE), crayfish trap (CRAYTR), electrofishing (ELFISH), fyke net (FYKNET), trammel net (TRAMML), vertical gillnets of different mesh sizes (VBN0XX), and different types of fyke nets (FYKNED and FYKNEL)
#spname: Species name (all YELLOWPERCH)
#length: Total Length (nearest mm) at capture
#weight: Weight (nearest 0.1 or 1 g) at capture

#One row = one fish
#
##########
# 1. Did data load?
###########

head(perch)
tail(perch)
# No extra columns, no incomplete rows at the bottom

##########
# 2. Are data types correct?
##############

sapply(perch, class)

# Note that year4 contains the same info as sampledate.
# sampledate is a date. Let's pull it into lubridate

perch$sampledate <- mdy(perch$sampledate) #Month Date Year
head(perch$sampledate) 

# We can drop year4
# But let's first make sure that year4 DOES match the year in sampledate

table(perch$year4 == year(perch$sampledate))

# What is this doing?
# Try this: head(year(perch$sampledate))
# year() extracts just the year
# So, we are asking: does year4 equal the YEAR value of sampledate?

# This runs the test on every single row of data

# the table() command tallies up the values. In this case, all the values were TRUE
# meaning that the year4 values were all the same as the year(sampledate) values

# So, we can drop year4

perch <- perch %>%
  select(-year4)

# Everything else is correct datatype

###########
# 3. Check impossible values
###########

range(perch$sampledate) #k
range(perch$length) #k
range(perch$weight, na.rm=TRUE) # metadata did say to nearest 0.1 g.

table(is.na(perch$weight)) #we do have weights for most. Not sure what NA means here.

#####################
# 4. Check factors  #
#####################

levels(perch$lakeid) #Only one lake. Let's drop the column
levels(perch$gearid) # Appears to match metadata
levels(perch$spname) #only one species. Let's drop it.

perch <- perch %>%
  select(-lakeid) %>%
  select(-spname)

# Data are ready!

# Go to next file